/* LIBGEGL - The GEGL Library
 * Copyright (C) 1995-1997 Peter Mattis and Spencer Kimball
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef __GEGL_CPU_ACCEL_PRIV_H__
#define __GEGL_CPU_ACCEL_PRIV_H__

G_BEGIN_DECLS

#include "gegl-cpuaccel.h"

/* for internal use only */
void               gegl_cpu_accel_set_use     (gboolean use);


G_END_DECLS

#endif  /* __GEGL_CPU_ACCEL_PRIV_H__ */
